class Calculator:
    def __init__(self):
        print("Hello!")
    def add(self, a, b):
        return a + b;
    def subtract(self, a, b):
        return a - b;
    def multiply(self, a, b):
        return a * b;
    def divide(self, a, b):
        return a / b;
